@@ -7,6 +7,7 @@
  - GitHub: https://github.com/Chendihe4975
 """
 import websockets
+import ssl
 from brotli import decompress
 from typing import List, Dict
 try:
@@ -16,7 +17,7 @@ except Exception:
 
 
 async def fetch_user_info(arcaea_id: int, recent_only: bool = False) -> List[Dict]:
-    async with websockets.connect("wss://arc.estertion.win:616/") as websocket:
+    async with websockets.connect("wss://arc.estertion.win:616/", ssl=ssl._create_unverified_context()) as websocket:
         await websocket.send(str(arcaea_id))
         result = list()
         while (data := await websocket.recv()) != "bye":
